Solvers
=======

.. module:: diofant.solvers

The *solvers* module in Diofant implements methods for
solving equations and inequalities.

.. toctree::
   :caption: Contents
   :name: solverstoc
   :maxdepth: 2

   solvers.rst
   inequalities.rst
   diophantine.rst
   ode.rst
   recurr.rst
   pde.rst
   utilities.rst
